@@ -57,6 +57,7 @@
 #include "networkAddress.h"
 #include "packetSource.h"
 #include "resolver.h"
+#include "cryptinit.hpp"
 
 #include "syncQueue.h"
 #include "syncCommand.h"
@@ -99,7 +100,7 @@ void createConnection(const PacketSourceEndpoint& remote_end, ConnectionList& cl
   sem.up();
 }
 
-void createConnectionResolver(PacketSourceResolverIt& it, ConnectionList& cl, uint16_t seqSize, SyncQueue& queue, mux_t mux, Semaphore& sem)
+void createConnectionResolver(PacketSourceResolverIt it, ConnectionList& cl, uint16_t seqSize, SyncQueue& queue, mux_t mux, Semaphore& sem)
 {
   createConnection(*it, cl, seqSize, queue, mux, sem);
 }
@@ -132,6 +133,8 @@ int main(int argc, char* argv[])
 
   gResolver.init();
 
+  initCrypto();
+
   ConnectionList cl;
   SyncQueue queue;
 
