@@ -76,7 +76,7 @@ UDPPacketSource::~UDPPacketSource()
   }
 }
 
-void UDPPacketSource::onResolve(PacketSourceResolverIt& it)
+void UDPPacketSource::onResolve(PacketSourceResolverIt it)
 {
   while(it != PacketSourceResolverIt()) {
     PacketSourceEndpoint e = *it;
