@@ -125,7 +125,11 @@ void SyncServer::start_accept()
   std::list<AcceptorsElement>::iterator it = acceptors_.begin();
   for(; it != acceptors_.end(); ++it) {
     if(!it->started_) {
+#if BOOST_VERSION >= 107000
+      SyncTcpConnection::pointer new_connection = SyncTcpConnection::create(it->acceptor_->get_executor());
+#else
       SyncTcpConnection::pointer new_connection = SyncTcpConnection::create(it->acceptor_->get_io_service());
+#endif
       conns_.push_back(new_connection);
       it->acceptor_->async_accept(new_connection->socket(),
                                   boost::bind(&SyncServer::handle_accept, this, new_connection, boost::asio::placeholders::error, it));
